@@ -1,7 +1,13 @@
 package Carp::POE;
+BEGIN {
+  $Carp::POE::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $Carp::POE::VERSION = '0.09';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use Carp ();
 use POE::Session;
 use base qw(Exporter);
@@ -9,7 +15,6 @@ use base qw(Exporter);
 our @EXPORT      = qw(confess croak carp);
 our @EXPORT_OK   = qw(cluck verbose);
 our @EXPORT_FAIL = qw(verbose);
-our $VERSION     = '0.08';
 
 # from POE::Session
 my ($file, $line) = (CALLER_FILE, CALLER_LINE);
@@ -43,13 +48,20 @@ sub _caller_info {
     my @args = @_;
     {
         package DB;
+BEGIN {
+  $DB::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $DB::VERSION = '0.09';
+}
         my @throw_away = caller(2);
         return "@args at $DB::args[$file] line $DB::args[$line]";
     }
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
